"""
This is the exercise from the first chapter of Head First Python.
It defines the print_lol() function which uses recursion to print
out inner lists.
"""
import sys

def print_lol(the_list, indent=False, level=0, fileOut=sys.stdout):
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, indent, level + 1, fileOut)
        else:
            if indent:
                for num in range(level):
                    print("\t", end='', file=fileOut)
            print(each_item, file=fileOut)